@@ -7,7 +7,7 @@
  */
 static char *WhatString[]= {
   "@(#)pstree Maemo 5 port - Version 1.0.0 by Pedram Veisi (C) 2010",
-  "@(#)EMail: pedramveisi@gmail.com"
+  "@(#)Email: pedramveisi@gmail.com"
 };
 
 #define MAXLINE 8192
